/***********************************************************************************************************************
 *
 * OpenBlueSky - NetBeans Platform Enhancements
 * Copyright (C) 2006-2012 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://openbluesky.java.net
 * SCM: https://bitbucket.org/tidalwave/openbluesky-src
 *
 **********************************************************************************************************************/
package it.tidalwave.netbeans.examples.nodes.example1.model;

import java.util.List;
import java.io.File;
import it.tidalwave.util.NotFoundException;
import it.tidalwave.netbeans.examples.nodes.example1.roles.*;
import org.junit.Before;
import org.junit.Test;
import static org.hamcrest.CoreMatchers.*;
import static org.junit.Assert.*;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public class CardinalityComputingTest 
  {
    private File directory;
    
    @Before
    public void setUp() 
      {
        directory = new File("target/directory");
        
        for (int i = 0; i < 9; i++)
          {
            for (int j = 0; j < i; j++)
              {
                for (int k = 0; k < j; k++)
                  {
                    new File(String.format("%s/a%d/b%d/c%d", directory.getAbsolutePath(), i, j, k)).mkdirs();  
                  }
              }
          }
      }
    
    @Test
    public void testFileModel1WithCardinalityCalculator1() 
      {
        final FileModel1 fileModel = new FileModel1(directory.getAbsolutePath());
        final CardinalityCalculator1 cardinalityCalculator = new CardinalityCalculator1();
        assertThat(cardinalityCalculator.count(fileModel), is(120));
      }
    
    @Test
    public void testFileModel2WithCardinalityCalculator2() 
      {
        final FileModel2 fileModel = new FileModel2(directory.getAbsolutePath());
        final CardinalityCalculator2 cardinalityCalculator = new CardinalityCalculator2();
        assertThat(cardinalityCalculator.count(fileModel), is(120));
      }
    
    @Test
    public void testFileModel2WithCardinalityCalculator3() 
      {
        final FileModel2 fileModel = new FileModel2(directory.getAbsolutePath());
        final CardinalityCalculator3 cardinalityCalculator = new CardinalityCalculator3();
        assertThat(cardinalityCalculator.count(fileModel), is(120));
      }
    
    @Test
    public void testFileModel2WithCardinalityCalculator4() 
      {
        final FileModel2 fileModel = new FileModel2(directory.getAbsolutePath());
        final CardinalityCalculator4 cardinalityCalculator = new CardinalityCalculator4();
        assertThat(cardinalityCalculator.count(fileModel), is(120));
      }
    
    @Test
    public void testCardinalityExample()
      throws NotFoundException
      {
        final CardinalityExample cardinalityExample = new CardinalityExample();
        
        assertThat(cardinalityExample.countFilesInPath(directory.getAbsolutePath()), is(120));
      }
    
    @Test
    public void testFlattenerExample()
      throws NotFoundException
      {
        final FlattenerExample flattenerExample = new FlattenerExample();
        final List<FileModel2> list = flattenerExample.findFilesInPath(directory.getAbsolutePath());
        System.err.println(list);
          
        assertThat(list.size(), is(120));
      }
  }